@@ -66,7 +66,7 @@ sub max {
 sub span {
     my $self = shift();
 
-    return $self->upper() - $self->lower();
+    return ($self->upper() - $self->lower()) || 1;
 }
 
 sub combine {
